pub trait WithLapack<D: Data + WithLapackData, I: Dimension> {
// Required method
fn with_lapack(self) -> ArrayBase<D::D, I>;
}Expand description
Add the Lapack bound to the floating point of a dataset
This helper trait is introduced to avoid leaking Lapack + Scalar bounds to the outside which
causes ambiguities when calling functions like abs for num_traits::Float and
Cauchy::Scalar. We are only using real values here, but the LAPACK routines
require that Cauchy::Scalar is implemented.